@@ -1,16 +1,15 @@
-GRM <- function(x, chunk = 1L) {
+GRM <- function(x, which.snps = x@snps$chr %in% getOption("gaston.autosomes"), chunk = 1L) {
   if(!x@standardize_mu_sigma & !x@standardize_p) {
     if(!is.null(x@p)) x@standardize_p <- TRUE
     else stop("Can't center/scale x for LD computation (use set.stat)\n")
   }
 
   if(x@standardize_mu_sigma) {
-    w <- ifelse(x@sigma == 0, 0, 1/x@sigma/sqrt(ncol(x)))   ### BEWARE ncol(x)-1 !!!
-    K <- .Call('gg_Kinship', PACKAGE = 'gaston', x@bed, x@mu, w, chunk) 
-  } else if(x@standardize_p) 
-    K <- .Call('gg_Kinship_p', PACKAGE = 'gaston', x@bed, x@p, chunk)
-  else 
-    stop("bed.matrix must be centered/scaled for GRM computation")
+    w <- ifelse(x@sigma == 0, 0, 1/x@sigma/sqrt(sum(which.snps)-1))   ### BEWARE q-1 !!!
+    K <- .Call('gg_Kinship_w', PACKAGE = 'gaston', x@bed, x@mu[which.snps], w[which.snps], which.snps, chunk) 
+  } else { 
+    K <- .Call('gg_Kinship_pw', PACKAGE = 'gaston', x@bed, x@p[which.snps], which.snps, chunk)
+  }
 
   if(!is.null(x@ped$id)) {
     if(anyDuplicated(x@ped$id) == 0) 
@@ -34,3 +33,4 @@ reshape.GRM <- function(K, include = c(-Inf, +Inf), exclude) {
   j <- J[ww];
   data.frame(i = i, j = j, id_i = rownames(K)[i], id_j = colnames(K)[j], k = R[ww])
 }
+
