@@ -92,27 +92,34 @@ struct paraWald : public Worker {
         max_h2 = h2;
       }
 
-      // *********** CALCUL DES BLUPS ************************
-      // Attention P0y n'est que (P0y)b, les n-p dernières composantes ! (les p premières sont nulles)
-      sigmab = sigma.bottomRows(n-p);
-      omega = h2 * sigmab.asDiagonal() * P0y;
+      // les SNPs monomorphes entrainent des vraisemblances mal définies
+      if(std::isfinite(A.likelihood)) {
+        // *********** CALCUL DES BLUPS ************************
+        // Attention P0y n'est que (P0y)b, les n-p dernières composantes ! (les p premières sont nulles)
+        sigmab = sigma.bottomRows(n-p);
+        omega = h2 * sigmab.asDiagonal() * P0y;
 
-      // Xb' Xb
-      MatrixXd xtx( MatrixXd(r,r).setZero().selfadjointView<Lower>().rankUpdate( x.bottomRows(n-p).transpose() ));
-      MatrixXd xtx0( xtx );
-      MatrixXd xtxi(r,r); // et son inverse
-      double d, ld;
-      sym_inverse(xtx0, xtxi, d, ld, 1e-5); // détruit xtx0
+        // Xb' Xb
+        MatrixXd xtx( MatrixXd(r,r).setZero().selfadjointView<Lower>().rankUpdate( x.bottomRows(n-p).transpose() ));
+        MatrixXd xtx0( xtx );
+        MatrixXd xtxi(r,r); // et son inverse
+        double d, ld;
+        sym_inverse(xtx0, xtxi, d, ld, 1e-5); // détruit xtx0
 
-      z = y;
-      z.tail(n-p) -= omega + (1-h2)*P0y;
-      beta = xtxi * x.bottomRows(n-p).transpose() * z.bottomRows(n-p);
-      // ************ FIN DU CALCUL DES BLUPS ******************
+        z = y;
+        z.tail(n-p) -= omega + (1-h2)*P0y;
+        beta = xtxi * x.bottomRows(n-p).transpose() * z.bottomRows(n-p);
+        // ************ FIN DU CALCUL DES BLUPS ******************
+  
+        H2[i-beg] = h2;
+        BETA[i-beg] = beta(r-1);
+        SDBETA[i-beg] = sqrt(v*XViXi(r-1,r-1));
+      } else {
+        H2[i-beg] = h2;
+        BETA[i-beg] = 0;
+        SDBETA[i-beg] = 0;
+      }
 
-      // std::cout << h2 << " ";
-      H2[i] = h2;
-      BETA[i] = beta(r-1);
-      SDBETA[i] = sqrt(v*XViXi(r-1,r-1));
 
       // remettre à jour min_h2 et max_h2
       if((i - beg + 1)%BLOCK == 0) {
